==> mediawiki-1.15.1.tgz: mediawiki/languages/messages/MessagesUg_latn.php <==
<?php
/** Uighur (Latin) (Uyghurche‎ / ئۇيغۇرچە (Latin))
 *
 * See MessagesQqq.php for message documentation incl. usage of parameters
 * To improve a translation please visit http://translatewiki.net
 *
 * @ingroup Language
 * @file
 *
 * @author Jose77
 * @author M.erdem
 * @author לערי ריינהארט
 */

$rtl = true;

$messages = array(
# Dates
'sunday'    => 'Yekshenbe',
'monday'    => 'Düshenbe',
'tuesday'   => 'Seyshenbe',
'wednesday' => 'Charshenbe',
'thursday'  => 'Peyshenbe',
'friday'    => 'Jüme',
'saturday'  => 'Shenbe',
'january'   => 'Yanwar',
'february'  => 'Féwral',
'march'     => 'Mart',
'april'     => 'Aprél',
'june'      => 'Iyun',
'july'      => 'Iyul',
'august'    => 'Awghust',
'september' => 'Séntebr',
'october'   => 'Öktebir',
'november'  => 'Noyabr',
'december'  => 'Dékabr',
'may'       => 'May',

'qbedit'     => 'Uzgartish',
'mypage'     => 'Mening beti',
'navigation' => 'Körüsh',

'search'           => 'Izdash',
'searchbutton'     => 'Izdash',
'go'               => 'Kuchush',
'searcharticle'    => 'Kuchush',
'history_short'    => 'Tarih',
'printableversion' => 'Basma Nushisi',
'permalink'        => 'Menggülük bet',
'edit'             => 'Uzgartish',
'delete'           => 'Yukhutush',
'protect'          => 'Koghdash',
'talkpagelinktext' => 'Monazire',
'talk'             => 'Monazire',
'toolbox'          => 'Qural sanduqlari',
'otherlanguages'   => 'Bashqa tillarda',
'jumptosearch'     => 'izdash',

# All link text and link target definitions of links into project namespace that get used by other message strings, with the exception of user group pages (see grouppage) and the disambiguation template definition (see disambiguations).
'currentevents'        => 'Hazirqi weqeler',
'edithelp'             => 'Uzgartish yardemi',
'mainpage'             => 'Bash Bet',
'mainpage-description' => 'Bash Bet',
'portal'               => 'Tor Jemiyiti',

'ok'             => 'MAQUL',
'editsection'    => 'uzgartish',
'editold'        => 'uzgartish',
'red-link-title' => '$1 (bet yoq)',

# Short words for each namespace, by default used in the namespace tab in monobook
'nstab-main'    => 'Bet',
'nstab-user'    => 'Ishletkuqi tor beti',
'nstab-special' => 'Alahide betleri',
'nstab-help'    => 'Yardem beti',

# Login and logout pages
'yourname'           => 'Ishletkuqi ismi:',
'yourpassword'       => 'Achkuch:',
'yourpasswordagain'  => 'Achkuchni khayta besing:',
'login'              => 'Kirish',
'logout'             => 'Chiqish',
'userlogout'         => 'Chikish',
'gotaccountlink'     => 'Kirish',
'youremail'          => 'Élxet:',
'username'           => 'Ishletkuqi ismi:',
'yourlanguage'       => 'Til:',
'email'              => 'Élxet:',
'loginlanguagelabel' => 'Til: $1',

# Edit pages
'summary'      => 'Hulasa:',
'minoredit'    => 'Bu Kichik Uzgartish',
'watchthis'    => 'Bu Batka Kharang',
'savearticle'  => 'Betni saqlang',
'showpreview'  => 'Aldinala kurux',
'showdiff'     => 'Uzgurushlerni kursutung',
'loginreqlink' => 'kirish',
'newarticle'   => '(Yéngi)',

# Search results
'prevn'       => 'aldinqi $1',
'nextn'       => 'kéyinki $1',
'powersearch' => 'Izdash',

# Preferences page
'searchresultshead'     => 'Izdash',
'timezoneregion-asia'   => 'Asiya',
'timezoneregion-europe' => 'Yawropa',

# Recent changes
'recentchanges' => 'Yéngi özgirish',

# Recent changes linked
'recentchangeslinked'      => 'Yéqinqi özgirishler',
'recentchangeslinked-page' => 'Betning ismi:',

# Upload
'upload'          => 'Yéngi höjjet kirgüzush',
'uploadbtn'       => 'Yengi Hujjat Kirguzush',
'filedesc'        => 'Hulasa',
'watchthisupload' => 'Bu Batka Kharang',

# File description page
'filehist-user' => 'Ishletkuchi',

# File deletion
'filedelete-submit' => 'Yukhutush',

# Random page
'randompage' => 'Halighan Tor Beti',

'brokenredirects-edit'   => '(uzgartish)',
'brokenredirects-delete' => '(yukhutush)',

# Miscellaneous special pages
'newpages'          => 'Yéngi betler',
'newpages-username' => 'Ishletkuqi ismi:',
'move'              => 'Yotkash',

# Book sources
'booksources-go' => 'Kuchush',

# Special:AllPages
'nextpage'       => 'Kéyinki bet ($1)',
'prevpage'       => 'Aldinqi bet ($1)',
'allpagessubmit' => 'Kuchush',

# Watchlist
'watchlist'     => 'Men kharawatkhan tor betleri',
'watch'         => 'Karang',
'watchthispage' => 'Bu Batka Kharang',

# Restrictions (nouns)
'restriction-edit' => 'Uzgartish',
'restriction-move' => 'Yotkash',

# Undelete
'undelete-search-submit' => 'Izdash',

'sp-contributions-submit' => 'Izdash',

# What links here
'whatlinkshere'      => 'Bashqa tor betler',
'whatlinkshere-page' => 'Bet:',

# Block/unblock
'ipblocklist-submit' => 'Izdash',

# Move page
'move-watch' => 'Bu Batka Kharang',

# Namespace 8 related
'allmessages' => 'System havarleri',

# Tooltip help for the actions
'tooltip-pt-logout' => 'Chikish',
'tooltip-ca-move'   => 'Bu batni yotkang',
'tooltip-search'    => 'Izdash {{SITENAME}}',
'tooltip-p-logo'    => 'Bash Bet',

# Special:NewFiles
'ilsubmit' => 'Izdash',

# Trackbacks
'trackbackremove' => '([$1 Yukhutush])',

# action=purge
'confirm_purge_button' => 'Maqul',

# Multipage image navigation
'imgmultipageprev' => '← aldinqi bet',
'imgmultipagenext' => 'kéyinki bet →',
'imgmultigo'       => 'Kuchush!',

# Table pager
'table_pager_next'         => 'Kéyinki bet',
'table_pager_prev'         => 'Aldinqi bet',
'table_pager_first'        => 'Birinchi bet',
'table_pager_last'         => 'Eng axirqi bet',
'table_pager_limit_submit' => 'Kuchush',

# Special:SpecialPages
'specialpages' => 'Alahide tor betleri',

);

==> mediawiki-1.18.1.tgz: mediawiki/languages/messages/MessagesUg_latn.php <==
<?php
/** Uyghur (Latin script) (Uyghurche‎)
 *
 * See MessagesQqq.php for message documentation incl. usage of parameters
 * To improve a translation please visit http://translatewiki.net
 *
 * @ingroup Language
 * @file
 *
 * @author Jose77
 * @author M.erdem
 * @author לערי ריינהארט
 */

$rtl = true;

$messages = array(
# Dates
'sunday'        => 'Yekshenbe',
'monday'        => 'Düshenbe',
'tuesday'       => 'Seyshenbe',
'wednesday'     => 'Charshenbe',
'thursday'      => 'Peyshenbe',
'friday'        => 'Jüme',
'saturday'      => 'Shenbe',
'january'       => 'Yanwar',
'february'      => 'Féwral',
'march'         => 'Mart',
'april'         => 'Aprél',
'may_long'      => 'May',
'june'          => 'Iyun',
'july'          => 'Iyul',
'august'        => 'Awghust',
'september'     => 'Séntebr',
'october'       => 'Öktebir',
'november'      => 'Noyabr',
'december'      => 'Dékabr',
'may-gen'       => 'May',
'september-gen' => 'Séntebr',
'october-gen'   => 'Öktebir',
'november-gen'  => 'Noyabr',
'december-gen'  => 'Dékabr',
'jan'           => '1-Ay',
'feb'           => '2-Ay',
'mar'           => '3-Ay',
'apr'           => '4-Ay',
'may'           => 'May',
'jun'           => '6-Ay',
'jul'           => '7-Ay',
'aug'           => '8-Ay',
'sep'           => '9-Ay',
'oct'           => '10-Ay',
'nov'           => '11-Ay',
'dec'           => '12-Ay',

'mypage'     => 'Mening beti',
'navigation' => 'Körüsh',

# Cologne Blue skin
'qbedit'         => 'Uzgartish',
'qbspecialpages' => 'Alahida tor batleri',

'help'             => 'Yardem',
'search'           => 'Izdash',
'searchbutton'     => 'Izdash',
'go'               => 'Kuchush',
'searcharticle'    => 'Kuchush',
'history_short'    => 'Tarih',
'printableversion' => 'Basma Nushisi',
'permalink'        => 'Menggülük bet',
'edit'             => 'Uzgartish',
'delete'           => 'Yukhutush',
'protect'          => 'Koghdash',
'talkpagelinktext' => 'Monazire',
'talk'             => 'Monazire',
'toolbox'          => 'Qural sanduqlari',
'otherlanguages'   => 'Bashqa tillarda',
'jumptosearch'     => 'izdash',

# All link text and link target definitions of links into project namespace that get used by other message strings, with the exception of user group pages (see grouppage) and the disambiguation template definition (see disambiguations).
'currentevents'        => 'Hazirqi weqeler',
'edithelp'             => 'Uzgartish yardemi',
'mainpage'             => 'Bash Bet',
'mainpage-description' => 'Bash Bet',
'portal'               => 'Tor Jemiyiti',

'ok'             => 'MAQUL',
'editsection'    => 'uzgartish',
'editold'        => 'uzgartish',
'red-link-title' => '$1 (bet yoq)',

# Short words for each namespace, by default used in the namespace tab in monobook
'nstab-main'    => 'Bet',
'nstab-user'    => 'Ishletkuqi tor beti',
'nstab-special' => 'Alahide betleri',
'nstab-help'    => 'Yardem beti',

# Login and logout pages
'yourname'           => 'Ishletkuqi ismi:',
'yourpassword'       => 'Achkuch:',
'yourpasswordagain'  => 'Achkuchni khayta besing:',
'login'              => 'Kirish',
'logout'             => 'Chiqish',
'userlogout'         => 'Chikish',
'gotaccountlink'     => 'Kirish',
'loginlanguagelabel' => 'Til: $1',

# Special:PasswordReset
'passwordreset-username' => 'Ishletkuchi ismi:',

# Edit pages
'summary'      => 'Hulasa:',
'minoredit'    => 'Bu Kichik Uzgartish',
'watchthis'    => 'Bu Batka Kharang',
'savearticle'  => 'Betni saqlang',
'showpreview'  => 'Aldinala kurux',
'showdiff'     => 'Uzgurushlerni kursutung',
'loginreqlink' => 'kirish',
'newarticle'   => '(Yéngi)',

# Search results
'prevn'       => 'aldinqi {{PLURAL:$1|$1}}',
'nextn'       => 'kéyinki {{PLURAL:$1|$1}}',
'powersearch' => 'Izdash',

# Preferences page
'prefs-rc'              => 'Yengi uzgurush',
'searchresultshead'     => 'Izdash',
'timezoneregion-asia'   => 'Asiya',
'timezoneregion-europe' => 'Yawropa',
'youremail'             => 'Élxet:',
'username'              => 'Ishletkuqi ismi:',
'yourlanguage'          => 'Til:',
'email'                 => 'Élxet:',

# Recent changes
'recentchanges' => 'Yéngi özgirish',

# Recent changes linked
'recentchangeslinked'         => 'Yéqinqi özgirishler',
'recentchangeslinked-feed'    => 'Yéqinqi özgirishler',
'recentchangeslinked-toolbox' => 'Yéqinqi özgirishler',
'recentchangeslinked-page'    => 'Betning ismi:',

# Upload
'upload'          => 'Yéngi höjjet kirgüzush',
'uploadbtn'       => 'Yengi Hujjat Kirguzush',
'filedesc'        => 'Hulasa',
'watchthisupload' => 'Bu Batka Kharang',

# File description page
'filehist-user' => 'Ishletkuchi',

# File deletion
'filedelete-submit' => 'Yukhutush',

# Random page
'randompage' => 'Halighan Tor Beti',

'brokenredirects-edit'   => 'uzgartish',
'brokenredirects-delete' => 'yukhutush',

# Miscellaneous special pages
'newpages'          => 'Yéngi betler',
'newpages-username' => 'Ishletkuqi ismi:',
'move'              => 'Yotkash',
'movethispage'      => 'Bu batni yotkang',

# Book sources
'booksources-go' => 'Kuchush',

# Special:AllPages
'nextpage'       => 'Kéyinki bet ($1)',
'prevpage'       => 'Aldinqi bet ($1)',
'allpagessubmit' => 'Kuchush',

# Special:LinkSearch
'linksearch-ok' => 'Izdash',

# Watchlist
'watchlist'     => 'Men kharawatkhan tor betleri',
'watch'         => 'Karang',
'watchthispage' => 'Bu Batka Kharang',

# Restrictions (nouns)
'restriction-edit' => 'Uzgartish',
'restriction-move' => 'Yotkash',

# Undelete
'undelete-search-submit' => 'Izdash',

'sp-contributions-talk'   => 'Monazire',
'sp-contributions-submit' => 'Izdash',

# What links here
'whatlinkshere'      => 'Bashqa tor betler',
'whatlinkshere-page' => 'Bet:',

# Block/unblock
'ipblocklist-submit' => 'Izdash',

# Move page
'movearticle' => 'Yotkigen beti:',
'move-watch'  => 'Bu Batka Kharang',
'movepagebtn' => 'Yotkigen beti',

# Namespace 8 related
'allmessages' => 'System havarleri',

# Tooltip help for the actions
'tooltip-pt-logout' => 'Chikish',
'tooltip-ca-move'   => 'Bu batni yotkang',
'tooltip-search'    => 'Izdash {{SITENAME}}',
'tooltip-p-logo'    => 'Bash Bet',

# Special:NewFiles
'ilsubmit' => 'Izdash',

# Trackbacks
'trackbackremove' => '([$1 Yukhutush])',

# action=purge
'confirm_purge_button' => 'Maqul',

# Multipage image navigation
'imgmultipageprev' => '← aldinqi bet',
'imgmultipagenext' => 'kéyinki bet →',
'imgmultigo'       => 'Kuchush!',

# Table pager
'table_pager_next'         => 'Kéyinki bet',
'table_pager_prev'         => 'Aldinqi bet',
'table_pager_first'        => 'Birinchi bet',
'table_pager_last'         => 'Eng axirqi bet',
'table_pager_limit_submit' => 'Kuchush',

# Special:SpecialPages
'specialpages' => 'Alahide tor betleri',

);
